//
//  SlideShowControllerViewController.swift
//  ImageViewer
//
//  Created by freund on 10/20/18.
//  Copyright © 2018 Stephen Freund. All rights reserved.
//

import UIKit

/**
 
 A simple controller that shows images from the web in a second
 ImageViewController.
 
 This class demonstrates how to create and use ImageSource objects.
 
 */
class SlideShowControllerViewController: UIViewController {
  
  private let urls: [String:URL] = [
    "Wally" : "http://www.cs.williams.edu/~freund/wally.jpg",
    "Cassini" : "http://www.jpl.nasa.gov/images/cassini/20090202/pia03883-full.jpg",
    "Earth" : "https://photojournal.jpl.nasa.gov/jpeg/PIA18033.jpg",
    "Saturn" : "https://photojournal.jpl.nasa.gov/jpeg/PIA06193.jpg"
    ].mapValues( { URL(string: $0)! })
  
  
  // MARK: - Navigation
  
  // In a storyboard-based application, you will often want to do a little preparation before navigation
  override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
    
    var destinationViewController = segue.destination
    
    
    if let navigationController = destinationViewController as? UINavigationController {
      destinationViewController = navigationController.topViewController ?? destinationViewController
    }
    
    if let imageViewController = destinationViewController as? ImageViewController,
      let identifier = segue.identifier {
      if let url = urls[identifier] {
        // load from URL
        imageViewController.imageSource = ImageSource() {
          if let contents = try? Data(contentsOf: url) {
            return UIImage(data: contents)
          } else {
            return nil
          }
        }
      } else {
        // load from Assets
        imageViewController.imageSource = ImageSource() {
          return UIImage(named: identifier)
        }
      }
      imageViewController.title = identifier
    }
  }
}

